@@ -20,7 +20,7 @@ typedef struct {
 	guint              timeout_id;
 
 	GUdevDevice *dev;
-	const char *dev_path;
+	char *dev_path;
 	int device_id;
 	BufferDrvData *buffer_data;
 } DrvData;
@@ -108,19 +108,6 @@ read_light (gpointer user_data)
 	return G_SOURCE_CONTINUE;
 }
 
-static gboolean
-iio_buffer_light_discover (GUdevDevice *device)
-{
-	if (!drv_check_udev_sensor_type (device, "iio-buffer-als", NULL))
-		return FALSE;
-
-	if (!is_buffer_usable (device))
-		return FALSE;
-
-	g_debug ("Found IIO buffer ALS at %s", g_udev_device_get_sysfs_path (device));
-	return TRUE;
-}
-
 static void
 iio_buffer_light_set_polling (SensorDevice *sensor_device,
 			      gboolean state)
@@ -152,16 +139,9 @@ iio_buffer_light_open (GUdevDevice *device)
 {
 	SensorDevice *sensor_device;
 	DrvData *drv_data;
-	g_autofree char *trigger_name = NULL;
 	BufferDrvData *buffer_data;
 
-	/* Get the trigger name, and build the channels from that */
-	trigger_name = get_trigger_name (device);
-	if (!trigger_name) {
-		g_debug ("Could not find trigger for %s", g_udev_device_get_sysfs_path (device));
-		return NULL;
-	}
-	buffer_data = buffer_drv_data_new (device, trigger_name);
+	buffer_data = buffer_drv_data_new (device);
 	if (!buffer_data)
 		return NULL;
 
@@ -176,7 +156,7 @@ iio_buffer_light_open (GUdevDevice *device)
 	drv_data = (DrvData *) sensor_device->priv;
 	drv_data->dev = g_object_ref (device);
 	drv_data->buffer_data = buffer_data;
-	drv_data->dev_path = g_udev_device_get_device_file (device);
+	drv_data->dev_path = get_device_file (device);
 
 	return sensor_device;
 }
@@ -192,6 +172,37 @@ iio_buffer_light_close (SensorDevice *sensor_device)
 	g_free (sensor_device);
 }
 
+static gboolean
+iio_buffer_light_discover (GUdevDevice *device)
+{
+	SensorDevice *sensor_device;
+	DrvData *drv_data;
+	gboolean buffer_usable = FALSE;
+
+	if (!drv_check_udev_sensor_type (device, "iio-buffer-als", NULL))
+		return FALSE;
+
+	sensor_device = iio_buffer_light_open (device);
+	if (!sensor_device)
+		return FALSE;
+
+	/* Attempt to read from the sensor */
+	drv_data = (DrvData *) sensor_device->priv;
+	enable_ring_buffer (drv_data->buffer_data);
+
+	buffer_usable = is_buffer_usable(drv_data->dev_path);
+
+	/* Close the sensor until it has been claimed */
+	disable_ring_buffer (drv_data->buffer_data);
+	iio_buffer_light_close (sensor_device);
+
+	if (!buffer_usable)
+		return FALSE;
+
+	g_debug ("Found IIO buffer ALS at %s", g_udev_device_get_sysfs_path (device));
+	return TRUE;
+}
+
 SensorDriver iio_buffer_light = {
 	.driver_name = "IIO Buffer Light sensor",
 	.type = DRIVER_TYPE_LIGHT,
