@@ -20,6 +20,7 @@
 #include <string.h>
 #include <errno.h>
 #include <stdio.h>
+#include <glib/gstdio.h>
 
 #define IIO_MIN_SAMPLING_FREQUENCY	10 /* Hz */
 
@@ -880,13 +881,14 @@ buffer_drv_data_free (BufferDrvData *buffer_data)
 }
 
 BufferDrvData *
-buffer_drv_data_new (GUdevDevice *device,
-		     const char  *trigger_name)
+buffer_drv_data_new (GUdevDevice *device)
 {
 	BufferDrvData *buffer_data;
+	g_autofree char *trigger_name = NULL;
 
 	buffer_data = g_new0 (BufferDrvData, 1);
 	buffer_data->dev_dir_name = g_udev_device_get_sysfs_path (device);
+	trigger_name = get_trigger_name (device);
 	if (trigger_name)
 		buffer_data->trigger_name = g_strdup (trigger_name);
 	buffer_data->device = g_object_ref (device);
@@ -904,21 +906,28 @@ buffer_drv_data_new (GUdevDevice *device,
 }
 
 gboolean
-is_buffer_usable (GUdevDevice *device)
+is_buffer_usable (char *path)
 {
-	g_autofree char *trigger_name = NULL;
-	BufferDrvData *buffer_data;
+	gboolean buffer_usable = FALSE;
+	g_autofd int fp = -1;
+	GPollFD fds;
 
-	trigger_name = get_trigger_name (device);
+	/* Attempt to read from the sensor buffer */
+	fp = g_open (path, O_RDONLY | O_NONBLOCK);
+	if (fp == -1) {
+	        g_warning ("Failed to open '%s': %s", path, g_strerror (errno));
+	} else {
+	        fds.fd = fp;
+	        fds.events = G_IO_IN | G_IO_ERR;
+	        g_poll (&fds, 1, 500);
 
-	/* Temporarily enable the buffer to ensure the kernel driver is buffer-capable */
-	buffer_data = buffer_drv_data_new (device, trigger_name);
-	if (!buffer_data)
-		return FALSE;
+	        if (fds.revents & G_IO_IN)
+	                buffer_usable = TRUE;
+	        else
+	                g_warning ("Buffer '%s' did not have data within 0.5s", path);
+	}
 
-	/* Destroy buffer information until actually needed (in the .open call) */
-	g_clear_pointer (&buffer_data, buffer_drv_data_free);
-	return TRUE;
+	return buffer_usable;
 }
 
 IIOSensorData *
